@@ -6,11 +6,10 @@
 
 
 import degget
-import generator_of_RU_words
-import install_packages
-import math_test
+import games_help
+import packages
 
 
 __author__ = 'Superior_6564'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __email__ = 'vip.klochayil@gmail.com'
